from sklearn.model_selection import train_test_split


def split(X, y, ts_pct=33):
    Xtr, Xts, ytr, yts = train_test_split(X, y, test_size=ts_pct / 100, random_state=42)
    return {"Xtr": Xtr, "ytr": ytr, "Xts": Xts, "yts": yts}



from idict import let


def copy(source=None, target=None, **kwargs):
    return {target: kwargs[source]}


trcopy = let(copy, source="Xtr", target="X") >> let(copy, source="ytr", target="y")
tscopy = let(copy, source="Xts", target="X") >> let(copy, source="yts", target="y")



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['lazyds',
 'lazyds.data',
 'lazyds.evaluation',
 'lazyds.learning',
 'lazyds.learning.supervised',
 'lazyds.learning.supervised.classification']

package_data = \
{'': ['*']}

install_requires = \
['arff2pandas>=1.0.1,<2.0.0',
 'idict>=0.211031.1,<0.211032.0',
 'pandas>=1.3.2,<2.0.0',
 'scikit-learn>=0.24.2,<0.25.0']

setup_kwargs = {
    'name': 'lazyds',
    'version': '0.211117.2',
    'description': 'Useful Data Science libraries wrapped by laziness',
    'long_description': None,
    'author': 'davips',
    'author_email': 'dpsabc@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<3.10',
}


setup(**setup_kwargs)



from arff2pandas import a2p
from idict import idict
from pandas import read_csv, DataFrame
from sklearn.preprocessing import LabelEncoder
from sklearn.datasets import fetch_openml


def Dataset(name="wdbc"):
    return idict(dataset(name))


def dataset(name="wdbc"):
    X, y = fetch_openml(name, return_X_y=True)
    return {"X": X, "y": y}


def File(name="iris.arff"):
    return idict(file(name))


def file(name="iris.arff"):
    if name.endswith(".arff"):
        with open(name) as f:
            return {"df": a2p.load(f)}
    elif name.endswith(".csv"):
        return {"df": read_csv(name)}


# def save(name=None):
# DataFrame({
#     'power@NUMERIC':[0.5,0.2],
#     'label@{good,bad}':['good','bad']
# })
# with open('sample.arff','w') as f:
#     a2p.dump(df,f)
#
#
# import pandas as pd
# df = pd.DataFrame({
#     'power@NUMERIC':[0.5,0.2],
#     'label@{good,bad}':['good','bad']
# })
# print(a2p.dumps(df))

def df2np(df):
    """
    >>> from lazyds.learning.supervised.classification.rf import rf
    >>> from idict import let
    >>> d = File() >> df2np >> let(rf, n=1)
    >>> d.model
    RandomForestClassifier(n_estimators=1)
    """
    le = LabelEncoder()
    X = df.drop(df.columns[[-1]], axis=1)
    y = le.fit_transform(df[df.columns[-1]])
    # raise Exception({"X": X, "y": y})
    return {"X": X, "y": y}
